@@ -14,7 +14,7 @@ use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 use utf8;
 
-our $VERSION  = 0.96012;
+our $VERSION  = 0.96013;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -39,8 +39,8 @@ sub run {
         'merges|m!',
     );
 
-    my %users;
-    my $commits = 0;
+    my @stats;
+    my $total_commits = 0;
     my $since = $option{since};
 
     if (!$since) {
@@ -67,6 +67,8 @@ sub run {
 
     my $periods = $option{periods} || 1;
     while ($periods--) {
+        my $commits = 0;
+        my %users;
         my @dates;
         if ($option{periods}) {
             @dates = $self->dates($option{period}, $option{periods}--);
@@ -96,11 +98,20 @@ sub run {
                 $option{changes} ? (changes => $self->changes($commits)) : (),
             };
         }
+        my $dates = join ' - ',
+            map {/=(.*)$/; $1}
+            @dates;
+        push @stats, {
+            commits => $commits,
+            period  => $dates,
+            users   => \%users,
+        };
+        $total_commits += $commits;
     }
 
     my $fmt = 'fmt_' . ($option{fmt} || 'table');
     if ($self->can($fmt)) {
-        $self->$fmt(\%users, $commits);
+        $self->$fmt(\@stats, $total_commits);
     }
 
     return;
@@ -108,7 +119,6 @@ sub run {
 
 sub dates {
     my ($self, $period, $count) = @_;
-    my @dates;
 
     $period
         = $period eq 'day'   ? 1
@@ -117,13 +127,16 @@ sub dates {
         : $period eq 'year'  ? 365
         :                      die "Unknown period '$option{period}' please choose one of day, week, month or year\n";
 
-    my $now = localtime;
+    my $until = localtime(time - ($count - 1) * $period * 24 * 60 * 60);
     my $since
-        = $now->wday == 1 ? localtime(time - 3 * $period * 24 * 60 * 60)->ymd
-        : $now->wday == 7 ? localtime(time - 2 * $period * 24 * 60 * 60)->ymd
-        :                   localtime(time - 1 * $period * 24 * 60 * 60)->ymd;
+        = $until->wday == 1 ? localtime(time - 3 * $count * $period * 24 * 60 * 60)
+        : $until->wday == 7 ? localtime(time - 2 * $count * $period * 24 * 60 * 60)
+        :                     localtime(time - 1 * $count * $period * 24 * 60 * 60);
 
-    return @dates;
+    return (
+        "--since=" . $since->ymd,
+        "--until=" . $until->ymd,
+    );
 }
 
 sub changes {
@@ -155,9 +168,11 @@ sub changes {
 }
 
 sub fmt_table {
-    my ($self, $users, $total) = @_;
+    my ($self, $stats, $total) = @_;
     my $fmt = "%-25s % 7d";
     my $max = 1;
+    my $users = $stats->[0]{users};
+    $total = $stats->[0]{commits};
 
     if ($option{changes}) {
         $fmt .= " % 9d % 9d % 5d";
@@ -212,7 +227,7 @@ git-committers - Stats on the number of commits by committer
 
 =head1 VERSION
 
-This documentation refers to git-committers version 0.96012
+This documentation refers to git-committers version 0.96013
 
 =head1 SYNOPSIS
 
@@ -221,6 +236,8 @@ This documentation refers to git-committers version 0.96012
  OPTIONS:
   -r --remote   Committers to remote branches
   -a --all      Committers to any branch (remote or local)
+  -c --changes  Add stats for lines added/removed
+  -C --commits  Output the individual commits (with --format json)
   -s --since[=]YYYY-MM-DD
                 Only commits since this date
   -u --until[=]YYYY-MM-DD
@@ -230,10 +247,13 @@ This documentation refers to git-committers version 0.96012
                    - table : shows the data in a simple table
                    - json  : returns the raw data as a json object
                    - perl  : Dump the data structure
-                   - csv   : Like table but as a csv
   -p --period=[day|week|month|year]
                 If --since is not specified this works out the date for the
                 last day/week/month/year
+  -P --periods[=]int
+                Generate stats for more than one period.
+  -M --min-commit[=]int
+                Only show stats for users with at least this number of commits
   -m --merges   Count merge commits
      --no-merges
                 Don't count merge commits
